@@ -61,8 +61,6 @@
  */
 
 #define MAX_HIDDEN_POPUPS       5
-#define MAX_TITLE_LENGTH        512 /* characters */
-#define EMPTY_PAGE              _("Blank page") /* Title for the empty page */
 
 #define EPHY_PAGE_TEMPLATE_ERROR         "/org/gnome/epiphany/page-templates/error.html"
 
@@ -80,9 +78,7 @@ struct _EphyWebViewPrivate {
 
   char *address;
   char *typed_address;
-  char *title;
-  char *loading_title;
-  char *status_message;
+  char *loading_message;
   char *link_message;
   GdkPixbuf *icon;
 
@@ -132,7 +128,6 @@ enum {
   PROP_POPUPS_ALLOWED,
   PROP_SECURITY,
   PROP_STATUS_MESSAGE,
-  PROP_EMBED_TITLE,
   PROP_TYPED_ADDRESS,
   PROP_IS_BLANK,
 };
@@ -369,9 +364,6 @@ ephy_web_view_get_property (GObject *object,
     case PROP_ADDRESS:
       g_value_set_string (value, priv->address);
       break;
-    case PROP_EMBED_TITLE:
-      g_value_set_string (value, priv->title);
-      break;
     case PROP_TYPED_ADDRESS:
       g_value_set_string (value, priv->typed_address);
       break;
@@ -399,7 +391,7 @@ ephy_web_view_get_property (GObject *object,
       g_value_set_enum (value, priv->security_level);
       break;
     case PROP_STATUS_MESSAGE:
-      g_value_set_string (value, priv->status_message);
+      g_value_set_string (value, ephy_web_view_get_status_message (EPHY_WEB_VIEW (object)));
       break;
     case PROP_IS_BLANK:
       g_value_set_boolean (value, priv->is_blank);
@@ -431,7 +423,6 @@ ephy_web_view_set_property (GObject *object,
     case PROP_NAVIGATION:
     case PROP_SECURITY:
     case PROP_STATUS_MESSAGE:
-    case PROP_EMBED_TITLE:
     case PROP_IS_BLANK:
       /* read only */
       break;
@@ -763,26 +754,12 @@ ephy_web_view_finalize (GObject *object)
 
   g_free (priv->address);
   g_free (priv->typed_address);
-  g_free (priv->title);
-  g_free (priv->status_message);
   g_free (priv->link_message);
-  g_free (priv->loading_title);
+  g_free (priv->loading_message);
 
   G_OBJECT_CLASS (ephy_web_view_parent_class)->finalize (object);
 }
 
-static char*
-get_title_from_address (const char *address)
-{
-  if (g_str_has_prefix (address, "file://"))
-    return g_strdup (address + 7);
-  else if (!strcmp (address, EPHY_ABOUT_SCHEME":overview") ||
-           !strcmp (address, "about:overview"))
-    return g_strdup (_("Most Visited"));
-  else
-    return ephy_string_get_host_name (address);
-}
-
 static void
 _ephy_web_view_set_is_blank (EphyWebView *view,
                              gboolean is_blank)
@@ -795,53 +772,27 @@ _ephy_web_view_set_is_blank (EphyWebView *view,
   }
 }
 
-static void
-ephy_web_view_set_title (EphyWebView *view,
-                         const char *view_title)
-{
-  EphyWebViewPrivate *priv = view->priv;
-  char *title = g_strdup (view_title);
-
-  if (title == NULL || g_strstrip (title)[0] == '\0') {
-    g_free (title);
-    title = priv->address ? get_title_from_address (priv->address) : NULL;
-
-    if (title == NULL || title[0] == '\0') {
-      g_free (title);
-      title = g_strdup (EMPTY_PAGE);
-    }
-  }
-
-  g_free (priv->title);
-  priv->title = ephy_string_shorten (title, MAX_TITLE_LENGTH);
-
-  g_object_notify (G_OBJECT (view), "embed-title");
-}
-
 static void
 title_changed_cb (WebKitWebView *web_view,
                   GParamSpec *spec,
                   gpointer data)
 {
   const char *uri;
-  char *title;
+  const char *title;
+  char *title_from_address = NULL;
   EphyWebView *webview  = EPHY_WEB_VIEW (web_view);
   EphyHistoryService *history = webview->priv->history_service;
 
   uri = webkit_web_view_get_uri (web_view);
+  title = webkit_web_view_get_title (web_view);
 
-  g_object_get (web_view, "title", &title, NULL);
-
-  ephy_web_view_set_title (webview, title);
-  
   if (!title && uri)
-    title = get_title_from_address (uri);
+    title = title_from_address = ephy_embed_utils_get_title_from_address (uri);
 
   if (uri && title && !ephy_web_view_is_history_frozen (webview))
     ephy_history_service_set_url_title (history, uri, title, NULL, NULL, NULL);
 
-  g_free (title);
-
+  g_free (title_from_address);
 }
 
 /*
@@ -986,19 +937,6 @@ ephy_web_view_class_init (EphyWebViewClass *klass)
                                                         "",
                                                         G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
-/**
- * EphyWebView:embed-title:
- *
- * Title for this embed.
- **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_EMBED_TITLE,
-                                   g_param_spec_string ("embed-title",
-                                                        "Title",
-                                                        "The view's title",
-                                                        EMPTY_PAGE,
-                                                        G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
-
 /**
  * EphyWebView:security-level:
  *
@@ -1513,6 +1451,38 @@ restore_zoom_level (EphyWebView *view,
                                            (EphyHistoryJobCallback)get_host_for_url_cb, view);
 }
 
+/**
+ * ephy_web_view_set_loading_message:
+ * @view: an #EphyWebView
+ * @address: the loading address
+ *
+ * Update @view's loading message
+ **/
+static void
+ephy_web_view_set_loading_message (EphyWebView *view,
+                                   const char *address)
+{
+  EphyWebViewPrivate *priv = view->priv;
+
+  g_clear_pointer (&priv->loading_message, g_free);
+  if (address) {
+    char *title;
+
+    title = ephy_embed_utils_get_title_from_address (address);
+
+    if (title != NULL && title[0] != '\0') {
+      /* translators: %s here is the address of the web page */
+      priv->loading_message = g_strdup_printf (_ ("Loading “%s”…"), title);
+    } else {
+      priv->loading_message = g_strdup (_("Loading…"));
+    }
+
+    g_free (title);
+  }
+
+  g_object_notify (G_OBJECT (view), "status-message");
+}
+
 static void
 ephy_web_view_location_changed (EphyWebView *view,
                                 const char *location)
@@ -1527,7 +1497,6 @@ ephy_web_view_location_changed (EphyWebView *view,
 
   if (location == NULL || location[0] == '\0') {
     ephy_web_view_set_address (view, NULL);
-    ephy_web_view_set_title (view, EMPTY_PAGE);
   } else if (g_str_has_prefix (location, EPHY_ABOUT_SCHEME":applications")) {
     SoupURI *uri = soup_uri_new (location);
     char *new_address;
@@ -1542,7 +1511,7 @@ ephy_web_view_location_changed (EphyWebView *view,
   } else {
     /* We do this to get rid of an eventual password in the URL. */
     ephy_web_view_set_address (view, location);
-    ephy_web_view_set_loading_title (view, location, TRUE);
+    ephy_web_view_set_loading_message (view, location);
   }
 
   ephy_web_view_set_link_message (view, NULL);
@@ -1585,11 +1554,7 @@ load_changed_cb (WebKitWebView *web_view,
     if (priv->address == NULL || priv->address[0] == '\0')
       ephy_web_view_set_address (view, loading_uri);
 
-    ephy_web_view_set_loading_title (view, loading_uri, TRUE);
-
-    g_free (priv->status_message);
-    priv->status_message = g_strdup (priv->loading_title);
-    g_object_notify (object, "status-message");
+    ephy_web_view_set_loading_message (view, loading_uri);
 
     /* Zoom level. */
     restore_zoom_level (view, loading_uri);
@@ -1639,13 +1604,7 @@ load_changed_cb (WebKitWebView *web_view,
     break;
   }
   case WEBKIT_LOAD_FINISHED:
-    g_free (priv->status_message);
-    priv->status_message = NULL;
-    g_object_notify (object, "status-message");
-    ephy_web_view_set_loading_title (view, NULL, FALSE);
-
-    if (priv->is_blank || !webkit_web_view_get_title (web_view))
-      ephy_web_view_set_title (view, NULL);
+    ephy_web_view_set_loading_message (view, NULL);
 
     /* Ensure we load the icon for this web view, if available. */
     _ephy_web_view_update_icon (view);
@@ -1808,8 +1767,6 @@ ephy_web_view_load_error_page (EphyWebView *view,
   }
   g_free (hostname);
 
-  ephy_web_view_set_title (view, page_title);
-
   _ephy_web_view_update_icon (view);
 
   stylesheet = get_style_sheet ();
@@ -1950,7 +1907,6 @@ ephy_web_view_init (EphyWebView *web_view)
 
   priv->is_blank = TRUE;
   priv->ever_committed = FALSE;
-  priv->title = g_strdup (EMPTY_PAGE);
   priv->document_type = EPHY_WEB_VIEW_DOCUMENT_HTML;
   priv->security_level = EPHY_WEB_VIEW_STATE_IS_UNKNOWN;
 
@@ -2178,52 +2134,6 @@ ephy_web_view_get_address (EphyWebView *view)
   return priv->address ? priv->address : "about:blank";
 }
 
-/**
- * ephy_web_view_get_title:
- * @view: an #EphyWebView
- *
- * Return value: the title of the web page displayed in @view
- **/
-const char *
-ephy_web_view_get_title (EphyWebView *view)
-{
-  return view->priv->title;
-}
-
-/**
- * ephy_web_view_set_loading_title:
- * @view: an #EphyWebView
- * @title: new loading title for @view
- * @is_address: %TRUE if @title is an address
- *
- * Update @view's loading title to @title, if @is_address is %TRUE it will
- * retrieve the title of the page at @title.
- **/
-void
-ephy_web_view_set_loading_title (EphyWebView *view,
-                                 const char *title,
-                                 gboolean is_address)
-{
-  EphyWebViewPrivate *priv = view->priv;
-  char *freeme = NULL;
-
-  g_free (priv->loading_title);
-  priv->loading_title = NULL;
-
-  if (is_address && title) {
-    title = freeme = get_title_from_address (title);
-  }
-
-  if (title != NULL && title[0] != '\0') {
-    /* translators: %s here is the address of the web page */
-    priv->loading_title = g_strdup_printf (_ ("Loading “%s”…"), title);
-  } else {
-    priv->loading_title = g_strdup (_ ("Loading…"));
-  }
-
-  g_free (freeme);
-}
-
 /**
  * ephy_web_view_is_loading:
  * @view: an #EphyWebView
@@ -2256,20 +2166,6 @@ ephy_web_view_load_failed (EphyWebView *view)
   return view->priv->load_failed;
 }
 
-/**
- * ephy_web_view_get_loading_title:
- * @view: an #EphyWebView
- *
- * Returns the loading title for @view.
- *
- * Return value: the provisional title of @view while loading
- **/
-const char *
-ephy_web_view_get_loading_title (EphyWebView *view)
-{
-  return view->priv->loading_title;
-}
-
 /**
  * ephy_web_view_get_icon:
  * @view: an #EphyWebView
@@ -2337,13 +2233,13 @@ ephy_web_view_get_status_message (EphyWebView *view)
 
   priv = view->priv;
 
-  if (priv->link_message && priv->link_message[0] != '\0') {
+  if (priv->link_message && priv->link_message[0] != '\0')
     return priv->link_message;
-  } else if (priv->status_message) {
-    return priv->status_message;
-  } else {
-    return NULL;
-  }
+
+  if (priv->loading_message)
+    return priv->loading_message;
+
+  return NULL;
 }
 
 /**
@@ -2768,48 +2664,13 @@ ephy_web_view_print (EphyWebView *view)
   settings = gtk_print_settings_new ();
   gtk_print_settings_set (settings,
                           GTK_PRINT_SETTINGS_OUTPUT_BASENAME,
-                          ephy_web_view_get_title (view));
+                          webkit_web_view_get_title (WEBKIT_WEB_VIEW (view)));
   webkit_print_operation_set_print_settings (operation, settings);
   webkit_print_operation_run_dialog (operation, NULL);
   g_object_unref (operation);
   g_object_unref (settings);
 }
 
-/**
- * ephy_web_view_get_title_composite:
- * @view: an #EphyView
- *
- * Returns the title of the web page loaded in @view.
- *
- * This differs from #ephy_web_view_get_title in that this function
- * will return a special title while the page is still loading.
- *
- * Return value: @view's web page's title. Will never be %NULL.
- **/
-const char *
-ephy_web_view_get_title_composite (EphyWebView *view)
-{
-  const char *title = "";
-  const char *loading_title;
-  gboolean is_loading;
-
-  g_return_val_if_fail (EPHY_IS_WEB_VIEW (view), NULL);
-
-  is_loading = ephy_web_view_is_loading (view);
-  loading_title = ephy_web_view_get_loading_title (view);
-  title = ephy_web_view_get_title (view);
-
-  if (view->priv->is_blank)
-  {
-    if (is_loading)
-      title = loading_title;
-    else
-      title = _("Blank page");
-  }
-
-  return title != NULL ? title : "";
-}
-
 static void
 web_resource_get_data_cb (WebKitWebResource *resource,
                           GAsyncResult *result,
